summaryrefslogtreecommitdiff
path: root/platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java
diff options
context:
space:
mode:
authorosana <osana.babayan@mapbox.com>2018-11-29 13:39:09 -0500
committer“osana” <osana.babayan@mapbox.com>2018-12-10 21:24:20 -0500
commit6a9706adafe993cec3f6990315bda9b0ecd1108f (patch)
tree05413a46425ff556b5c0af94a60c7eda61ae102d /platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java
parentebd87a5442772e9e840cd5c00be56cccfddb5c68 (diff)
downloadqtlocation-mapboxgl-6a9706adafe993cec3f6990315bda9b0ecd1108f.tar.gz
native should be called only with LatLngUnwrappedBoundsupstream/osana-latlngunwrapbounds
Diffstat (limited to 'platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java')
-rw-r--r--platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java11
1 files changed, 7 insertions, 4 deletions
diff --git a/platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java b/platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java
index a1d84f1fd4..5362f3ba86 100644
--- a/platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java
+++ b/platform/android/MapboxGLAndroidSDK/src/main/java/com/mapbox/mapboxsdk/snapshotter/MapSnapshotter.java
@@ -27,6 +27,7 @@ import com.mapbox.mapboxsdk.attribution.AttributionParser;
import com.mapbox.mapboxsdk.camera.CameraPosition;
import com.mapbox.mapboxsdk.maps.Style;
import com.mapbox.mapboxsdk.geometry.LatLngBounds;
+import com.mapbox.mapboxsdk.geometry.LatLngUnwrappedBounds;
import com.mapbox.mapboxsdk.log.Logger;
import com.mapbox.mapboxsdk.maps.TelemetryDefinition;
import com.mapbox.mapboxsdk.storage.FileSource;
@@ -288,7 +289,8 @@ public class MapSnapshotter {
String programCacheDir = FileSource.getInternalCachePath(context);
nativeInitialize(this, fileSource, options.pixelRatio, options.width,
- options.height, options.styleUrl, options.styleJson, options.region, options.cameraPosition,
+ options.height, options.styleUrl, options.styleJson,
+ LatLngUnwrappedBounds.from(options.region), options.cameraPosition,
options.showLogo, programCacheDir, options.localIdeographFontFamily);
}
@@ -339,10 +341,10 @@ public class MapSnapshotter {
/**
* Updates the snapshotter with a new {@link LatLngBounds}
*
* @param region the region
*/
@Keep
- public native void setRegion(LatLngBounds region);
+ public native void setRegion(LatLngUnwrappedBounds unwrappedRegion);
/**
* Updates the snapshotter with a new style url
@@ -570,7 +572,8 @@ public class MapSnapshotter {
protected native void nativeInitialize(MapSnapshotter mapSnapshotter,
FileSource fileSource, float pixelRatio,
int width, int height, String styleUrl, String styleJson,
- LatLngBounds region, CameraPosition position,
+ LatLngUnwrappedBounds unwrappedRegion,
+ CameraPosition position,
boolean showLogo, String programCacheDir,
String localIdeographFontFamily);
@@ -339,10 +341,10 @@ public class MapSnapshotter {
* Updates the snapshotter with a new {@link LatLngBounds}
*
- * @param region the region
+ * @param unwrappedRegion the region
*/